@@ -7,6 +7,7 @@ my @WORDS = qw(hello how are you today fantasy rumble forward down fast);
 
 my $sh = Term::Shelly->new();
 
+if (0) {
 $sh->out(
 "This is a demo of Term::Shelly. It is designed to show you some of the
 features of it. For this demo there is only a short number of features
@@ -19,9 +20,12 @@ completion system. The following words can be tab completed:
 " . join(" ", @WORDS)."
 Commands must start with a / (forward slash) and be at the beginning of 
 the line.");
+}
 
 $sh->{"completion_function"} = \&completer;
+$sh->prompt("Foo> ");
 
+$sh->out("Welcome!");
 
 while (1) {
 	$sh->do_one_loop();
@@ -41,7 +45,7 @@ sub completer {
 		$word = substr($curword,1);
 		@matches = map { "/$_" } grep(m/^\Q$word\E/i, @COMMANDS);
 	} else {
-		@matches = grep(m/\Q$curword\E/i, @WORDS);
+		@matches = grep(m/^\Q$curword\E/i, @WORDS);
 	}
 
 	return @matches;
